==> context_2012.05.30.20120611.orig.tar.gz: context-2012.05.30.20120611/texmf-dist/tex/context/base/mult-mps.lua <==
return {
    tex = {
        "btex", "etex", "verbatimtex",
    },
    shortcuts = {
        "..", "...", "--", "---", "&",
    },
    primitives = { -- to be checked
        "charcode", "day", "linecap", "linejoin", "miterlimit", "month", "pausing",
        "prologues", "showstopping", "time", "tracingcapsules", "tracingchoices", "mpprocset",
        "tracingcommands", "tracingequations", "tracinglostchars",
        "tracingmacros", "tracingonline", "tracingoutput", "tracingrestores",
        "tracingspecs", "tracingstats", "tracingtitles", "truecorners",
        "warningcheck", "year",
        "false", "nullpicture", "pencircle", "true",
        "and", "angle", "arclength", "arctime", "ASCII", "boolean", "bot",
        "char", "color", "cosd", "cycle", "decimal", "directiontime", "floor", "fontsize",
        "hex", "infont", "intersectiontimes", "known", "length", "llcorner",
        "lrcorner", "makepath", "makepen", "mexp", "mlog", "normaldeviate", "not",
        "numeric", "oct", "odd", "or", "path", "pair", "pen", "penoffset", "picture", "point",
        "postcontrol", "precontrol", "reverse", "rotated", "scaled",
        "shifted", "sind", "slanted", "sqrt", "str", "string", "subpath", "substring",
        "transform", "transformed", "ulcorner", "uniformdeviate", "unknown",
        "urcorner", "xpart", "xscaled", "xxpart", "xypart", "ypart", "yscaled", "yxpart",
        "yypart", "zscaled",
        "addto", "clip", "input", "interim", "let", "newinternal", "save", "setbounds",
        "shipout", "show", "showdependencies", "showtoken", "showvariable",
        "special",
        "begingroup", "endgroup", "of", "curl", "tension", "and", "controls",
        "interpath", "on", "off",
        "def", "vardef", "enddef", "expr", "suffix", "text", "primary", "secondary",
        "tertiary", "primarydef", "secondarydef", "tertiarydef",
        "randomseed", "also", "contour", "doublepath",
        "withcolor", "withpen", "dashed", "if", "else", "elseif", "fi", "for", "endfor", "forever", "exitif",
        "forsuffixes", "downto", "upto", "step", "until",
        "charlist", "extensible", "fontdimen", "headerbyte", "kern", "ligtable",
        "boundarychar", "chardp", "charext", "charht", "charic", "charwd", "designsize",
        "fontmaking", "charexists",
        "cullit", "currenttransform", "gfcorners", "grayfont", "hround",
        "imagerules", "lowres_fix", "nodisplays", "notransforms", "openit",
        "displaying", "currentwindow", "screen_rows", "screen_cols",
        "pixels_per_inch", "cull", "display", "openwindow", "numspecial",
        "totalweight", "autorounding", "fillin", "proofing", "tracingpens",
        "xoffset", "chardx", "granularity", "smoothing", "turningcheck", "yoffset",
        "chardy", "hppp", "tracingedges", "vppp",
        "extra_beginfig", "extra_endfig", "mpxbreak",
        "endinput",
        "message", "delimiters", "turningnumber", "errmessage",
        "readstring", "scantokens", "end", "outer", "inner", "write", "to", "readfrom",
        "withprescript", "withpostscript",
        "top", "bot", "lft", "rt", "ulft", "urt", "llft", "lrt",
        --
        "redpart", "greenpart", "bluepart", "cyanpart", "magentapart", "yellowpart", "blackpart", "greypart",
        "rgbcolor", "cmykcolor", "greycolor", "graycolor",
        "colormodel",  "graypart",
        "expandafter",
    },
    commands = {
        "beginfig", "endfig",
        "rotatedaround", "reflectedabout",
        "arrowhead",
        "currentpen", "currentpicture", "cuttings",
        "defaultfont", "extra_beginfig", "extra_endfig",
        "ditto", "EOF", "down",
        "evenly", "fullcircle", "halfcircle", "identity", "in", "left",
        "origin", "pensquare",  "quartercircle", "right",
        "unitsquare", "up", "withdots",
        "abs", "bbox", "ceiling", "center", "cutafter", "cutbefore", "dir",
        "directionpoint", "div", "dotprod", "intersectionpoint", "inverse", "mod",
        "round", "unitvector", "whatever",
        "cutdraw", "draw", "drawarrow", "drawdblarrow", "fill", "filldraw", "drawdot",
        "loggingall", "interact", "tracingall", "tracingnone",
        "pickup",
        "undraw", "unfill", "unfilldraw",
        "buildcycle", "dashpattern", "decr", "dotlabel", "dotlabels", "drawoptions",
        "incr", "label", "labels", "max", "min", "thelabel", "z",
        "beginchar", "blacker", "capsule_end", "change_width",
        "define_blacker_pixels", "define_corrected_pixels",
        "define_good_x_pixels", "define_good_y_pixels",
        "define_horizontal_corrected_pixels", "define_pixels",
        "define_whole_blacker_pixels", "define_whole_pixels",
        "define_whole_vertical_blacker_pixels",
        "define_whole_vertical_pixels", "endchar", "extra_beginchar",
        "extra_endchar", "extra_setup", "font_coding_scheme",
        "clearxy", "clearit", "clearpen", "shipit",
        "font_extra_space",
        "exitunless",
        "relax", "hide", "gobble", "gobbled", "stop",
        "blankpicture",
        "counterclockwise", "tensepath", "takepower", "direction",
        "softjoin", -- "magstep",
        "makelabel", -- "laboff",
        "rotatedabout", "flex", "superellipse", "erase", "image",
        "nullpen", "savepen", "clearpen", "penpos", "penlabels", -- "clear_pen_memory",
        "range", "numtok", "thru",
        "z", "laboff",
        "bye",
        --
        "red", "green", "blue", "cyan", "magenta", "yellow", "black", "white", "background",
        "graypart", "graycolor",
        --
        "mm", "pt", "dd", "bp", "cm", "pc", "cc", "in",
    },
    internals = { -- we need to remove duplicates above
        --
        "mitered", "rounded", "beveled", "butt", "squared",
        "eps", "epsilon", "infinity",
        "bboxmargin", "ahlength", "ahangle", "labeloffset", "dotlabeldiam", "defaultpen", "defaultscale", "join_radius",
        --
        "pen_lft", "pen_rt", "pen_top", "pen_bot", -- "pen_count_",
    },
}

==> context_2013.05.28.20130704.orig.tar.gz: context-2013.05.28.20130704/texmf-dist/tex/context/base/mult-mps.lua <==
return {
    tex = {
        "btex", "etex", "verbatimtex",
    },
    shortcuts = {
        "..", "...", "--", "---", "&",
    },
    primitives = { -- to be checked
        "charcode", "day", "linecap", "linejoin", "miterlimit", "month", "pausing",
        "prologues", "showstopping", "time", "tracingcapsules", "tracingchoices", "mpprocset",
        "tracingcommands", "tracingequations", "tracinglostchars",
        "tracingmacros", "tracingonline", "tracingoutput", "tracingrestores",
        "tracingspecs", "tracingstats", "tracingtitles", "truecorners",
        "warningcheck", "year",
        "false", "nullpicture", "pencircle", "true",
        "and", "angle", "arclength", "arctime", "ASCII", "boolean", "bot",
        "char", "color", "cosd", "cycle", "decimal", "directiontime", "floor", "fontsize",
        "hex", "infont", "intersectiontimes", "known", "length", "llcorner",
        "lrcorner", "makepath", "makepen", "mexp", "mlog", "normaldeviate", "not",
        "numeric", "oct", "odd", "or", "path", "pair", "pen", "penoffset", "picture", "point",
        "postcontrol", "precontrol", "reverse", "rotated", "scaled",
        "shifted", "sind", "slanted", "sqrt", "str", "string", "subpath", "substring",
        "transform", "transformed", "ulcorner", "uniformdeviate", "unknown",
        "urcorner", "xpart", "xscaled", "xxpart", "xypart", "ypart", "yscaled", "yxpart",
        "yypart", "zscaled",
        "addto", "clip", "input", "interim", "let", "newinternal", "save", "setbounds",
        "shipout", "show", "showdependencies", "showtoken", "showvariable",
        "special",
        "begingroup", "endgroup", "of", "curl", "tension", "and", "controls",
        "interpath", "on", "off",
        "def", "vardef", "enddef", "expr", "suffix", "text", "primary", "secondary",
        "tertiary", "primarydef", "secondarydef", "tertiarydef",
        "randomseed", "also", "contour", "doublepath",
        "withcolor", "withpen", "dashed", "if", "else", "elseif", "fi", "for", "endfor", "forever", "exitif", "within",
        "forsuffixes", "downto", "upto", "step", "until",
        "charlist", "extensible", "fontdimen", "headerbyte", "kern", "ligtable",
        "boundarychar", "chardp", "charext", "charht", "charic", "charwd", "designsize",
        "fontmaking", "charexists",
        "cullit", "currenttransform", "gfcorners", "grayfont", "hround",
        "imagerules", "lowres_fix", "nodisplays", "notransforms", "openit",
        "displaying", "currentwindow", "screen_rows", "screen_cols",
        "pixels_per_inch", "cull", "display", "openwindow", "numspecial",
        "totalweight", "autorounding", "fillin", "proofing", "tracingpens",
        "xoffset", "chardx", "granularity", "smoothing", "turningcheck", "yoffset",
        "chardy", "hppp", "tracingedges", "vppp",
        "extra_beginfig", "extra_endfig", "mpxbreak",
        "endinput",
        "message", "delimiters", "turningnumber", "errmessage",
        "readstring", "scantokens", "end", "outer", "inner", "write", "to", "readfrom",
        "withprescript", "withpostscript",
        "top", "bot", "lft", "rt", "ulft", "urt", "llft", "lrt",
        --
        "redpart", "greenpart", "bluepart", "cyanpart", "magentapart", "yellowpart", "blackpart", "greypart",
        "rgbcolor", "cmykcolor", "greycolor", "graycolor",
        "colormodel",  "graypart",
        "dashpart", "penpart",
--         "colorpart",
        "stroked", "filled", "textual", "clipped", "bounded",
        "expandafter",
    },
    commands = {
        "beginfig", "endfig",
        "rotatedaround", "reflectedabout",
        "arrowhead",
        "currentpen", "currentpicture", "cuttings",
        "defaultfont", "extra_beginfig", "extra_endfig",
        "ditto", "EOF", "down",
        "evenly", "fullcircle", "halfcircle", "identity", "in", "left",
        "origin", "pensquare",  "quartercircle", "right",
        "unitsquare", "up", "withdots",
        "abs", "bbox", "ceiling", "center", "cutafter", "cutbefore", "dir",
        "directionpoint", "div", "dotprod", "intersectionpoint", "inverse", "mod",
        "round", "unitvector", "whatever",
        "cutdraw", "draw", "drawarrow", "drawdblarrow", "fill", "filldraw", "drawdot",
        "loggingall", "interact", "tracingall", "tracingnone",
        "pickup",
        "undraw", "unfill", "unfilldraw",
        "buildcycle", "dashpattern", "decr", "dotlabel", "dotlabels", "drawoptions",
        "incr", "label", "labels", "max", "min", "thelabel", "z",
        "beginchar", "blacker", "capsule_end", "change_width",
        "define_blacker_pixels", "define_corrected_pixels",
        "define_good_x_pixels", "define_good_y_pixels",
        "define_horizontal_corrected_pixels", "define_pixels",
        "define_whole_blacker_pixels", "define_whole_pixels",
        "define_whole_vertical_blacker_pixels",
        "define_whole_vertical_pixels", "endchar", "extra_beginchar",
        "extra_endchar", "extra_setup", "font_coding_scheme",
        "clearxy", "clearit", "clearpen", "shipit",
        "font_extra_space",
        "exitunless",
        "relax", "hide", "gobble", "gobbled", "stop",
        "blankpicture",
        "counterclockwise", "tensepath", "takepower", "direction",
        "softjoin", -- "magstep",
        "makelabel", -- "laboff",
        "rotatedabout", "flex", "superellipse", "erase", "image",
        "nullpen", "savepen", "clearpen", "penpos", "penlabels", -- "clear_pen_memory",
        "range", "numtok", "thru",
        "z", "laboff",
        "bye",
        --
        "red", "green", "blue", "cyan", "magenta", "yellow", "black", "white", "background",
        "graypart", "graycolor",
        --
        "mm", "pt", "dd", "bp", "cm", "pc", "cc", "in",
    },
    internals = { -- we need to remove duplicates above
        --
        "mitered", "rounded", "beveled", "butt", "squared",
        "eps", "epsilon", "infinity",
        "bboxmargin", "ahlength", "ahangle", "labeloffset", "dotlabeldiam", "defaultpen", "defaultscale", "join_radius",
        --
        "pen_lft", "pen_rt", "pen_top", "pen_bot", -- "pen_count_",
    },
}
